 
--
-- 积分类：积分设置表，积分日志表*，积分商品表*，积分兑换订单表（针对积分商品表），礼品卡表（应该与优惠劵一起，这里补录） 
--

DROP TABLE IF EXISTS vs_points_set;
CREATE TABLE vs_points_set(
ps_id INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '积分设置ID',
ps_title VARCHAR(500) COMMENT '积分标题',
ps_type  SMALLINT   DEFAULT 0 COMMENT  '1获取2消费',
ps_code  INT  COMMENT '积分编码，如签到101，转发102，抽奖201，兑换202',
ps_point   INT    DEFAULT 1  COMMENT '兑换积分，如果是购物则是倍数',
ps_sort  INT   DEFAULT 100  COMMENT '权重',
ps_status   INT   DEFAULT 0  COMMENT '状态0无效1有效',
modified_time  INT    DEFAULT 0 COMMENT '最后修改时间',
PRIMARY KEY (ps_id)
) ENGINE = innodb COMMENT '积分设置表' DEFAULT CHARSET=utf8; 

DROP TABLE IF EXISTS vs_points_log;  
CREATE TABLE vs_points_log(
pl_id INT   NOT NULL AUTO_INCREMENT COMMENT '积分日志ID',
customer_id INT   NOT NULL COMMENT '用户ID',
ps_code VARCHAR(100) COMMENT '积分编码，如，购买100，签到101，转发102，抽奖201，兑换202，奖励301',
pl_biz VARCHAR(100) COMMENT '相关编码，如兑换订单号，购物订单号',
pl_point INT NOT NULL DEFAULT 0 COMMENT '变更积分数',
pl_type  SMALLINT NOT NULL DEFAULT 1 COMMENT '1获取2消费，与ps_type一致',
modified_time  INT   NOT NULL DEFAULT 0  COMMENT '积分日志生成时间',
PRIMARY KEY (pl_id)
) ENGINE = innodb COMMENT '用户积分日志表';


DROP TABLE IF EXISTS vs_points_product;
CREATE TABLE vs_points_product(
pp_id INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '积分商品ID',
pp_title VARCHAR(500) COMMENT '积分商品标题',
pp_type  SMALLINT   DEFAULT 0 COMMENT  '商品类型1实物商品0优惠劵',
pp_litpic  VARCHAR(500) COMMENT '积分商品图片',
pop_id   INT    DEFAULT 0  COMMENT '优惠劵batch_id或实物商品ID',
ps_id   INT    DEFAULT 0  COMMENT '积分设置ID，待定',
pp_point   INT    DEFAULT 0  COMMENT '兑换积分',
pp_sort  INT   DEFAULT 100  COMMENT '排序',
pp_status   INT   DEFAULT 0  COMMENT '商品状态0无效1有效',
modified_time  INT    DEFAULT 0 COMMENT '最后修改时间',
PRIMARY KEY (pp_id)
) ENGINE = innodb COMMENT '积分商品表' DEFAULT CHARSET=utf8;




DROP TABLE IF EXISTS vs_points_order;
CREATE TABLE vs_points_order(
po_id INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '积分订单ID',
customer_id   INT NOT NULL  DEFAULT 0  COMMENT '兑换用户ID',
po_ono    VARCHAR(500)  COMMENT '积分订单编码',
pp_id   INT NOT NULL  DEFAULT 0  COMMENT '积分商品ID',
pp_point   INT NOT NULL DEFAULT 0   COMMENT '单个兑换积分',
pp_num   INT NOT NULL DEFAULT 0   COMMENT '兑换数量',
po_point_total   INT NOT NULL COMMENT '兑换总积分',
po_status   INT NOT NULL  DEFAULT 0  COMMENT '兑换状态0无效1有效',
po_wlstatus  INT NOT NULL  DEFAULT 0  COMMENT '商品发货状态0未发货1已发货',
po_wlono   VARCHAR(500) DEFAULT '' COMMENT '物流单号',
po_shipping_time  INT  DEFAULT 0    COMMENT '发货时间',
po_shipping_tel   VARCHAR(500) DEFAULT '' COMMENT '收货电话',
po_shipping_user   VARCHAR(500) DEFAULT '' COMMENT '收货人',
po_province   VARCHAR(500) DEFAULT '' COMMENT '省份',
po_city   VARCHAR(500) DEFAULT '' COMMENT '城市',
po_district   VARCHAR(500) DEFAULT '' COMMENT '县区',
po_address   VARCHAR(500) DEFAULT '' COMMENT '地址',
modified_time  INT NOT NULL  DEFAULT 0 COMMENT '最后修改时间',
PRIMARY KEY (po_id)
) ENGINE = innodb COMMENT '积分订单表' DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS vs_giftcard;
CREATE TABLE vs_giftcard(
gc_id INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '礼品卡ID',
gc_title VARCHAR(300)  NOT NULL COMMENT '礼品卡标题',
gc_litpic VARCHAR(500)  NOT NULL COMMENT '礼品卡图片',
gc_type  TINYINT NOT NULL DEFAULT 0  COMMENT '礼品卡类型，0虚拟、1实物',
gc_content VARCHAR(5000) COMMENT '使用说明',
gc_user_type   INT NOT NULL  DEFAULT 0  COMMENT '0不限1会员等级',
gc_limit_num   INT NOT NULL  DEFAULT 0  COMMENT '每人限领数量0不限',
gc_limit_type   INT NOT NULL  DEFAULT 0  COMMENT '0固定时间1有效天数',
gc_time_start   INT NOT NULL  DEFAULT 0  COMMENT '限用时间开始',
gc_time_end   INT NOT NULL  DEFAULT 0  COMMENT ' 限用时间结束',
gc_time_limit   INT NOT NULL  DEFAULT 0  COMMENT '限用有效天数0为固定时间',
PRIMARY KEY (gc_id)
) ENGINE = innodb COMMENT '礼品卡表' DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS vs_giftcard_getlist;
CREATE TABLE vs_giftcard_getlist(
gg_id INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '领取记录ID',
gc_id INT NOT NULL  DEFAULT 0 COMMENT '礼品卡ID',
gg_used  TINYINT NOT NULL DEFAULT 0  COMMENT '领取后是否使用，0未、1已使用',
gg_from  TINYINT NOT NULL DEFAULT 0  COMMENT '来源，0领取、1兑换2退还',
customer_id   INT NOT NULL  DEFAULT 0  COMMENT '用户ID',
gg_byorder   INT NOT NULL  DEFAULT 0  COMMENT '订单ID，使用时对应的订单ID',
gg_usetime   INT NOT NULL  DEFAULT 0  COMMENT '使用时间',
PRIMARY KEY (gg_id)
) ENGINE = innodb COMMENT '礼品卡领取记录表' DEFAULT CHARSET=utf8;
